;------------------------------------------------------------------------------
; umfpu.inc
;
; Include file to define PIC to uM-FPU interface routines.
;
; @author Cam Thompson, Micromega Corporation
; Copyright (c) Micromega Corporation 2004. All rights reserved.
;
; @version	V1.0 September 20, 2004
; changes:
;	V1.0 - September 20, 2004
;	  - original code
;------------------------------------------------------------------------------

;-------------------- status bit definitions ----------------------------------

#define	status_Zero	dataByte, 0		;zero status bit (0-not zero, 1-zero)
#define	status_Sign	dataByte, 1		;sign status bit (0-positive, 1-negative)
#define	status_NaN	dataByte, 2		;NaN status bit (0-valid number, 1-NaN)
#define	status_Inf	dataByte, 3		;Infinity status bit (0-not infinite, 1-infinite)

;-------------------- register select macros ----------------------------------

selectA	macro	reg
	movlw	reg
	movwf	regA
	endm

selectB	macro	reg
	movlw	reg
	movwf	regB
	endm

;-------------------- global variables ----------------------------------------

	extern	regA, regB, dataByte

;-------------------- low level routines --------------------------------------

	extern		fpu_reset
	extern		fpu_sendOpcode
	extern		fpu_sendByte
	extern		fpu_readByte
	extern		fpu_traceDelay
	extern		fpu_readDelay

;-------------------- floating point routines ---------------------------------

	extern		fwriteA
	extern		fwriteB
	extern		fread
	extern		fset
	extern		fadd
	extern		fsub
	extern		fmul
	extern		fdiv
	extern		sqrt
	extern		log
	extern		log10
	extern		exp
	extern		exp10
	extern		sin
	extern		cos
	extern		tan
	extern		floor
	extern		ceil
	extern		round
	extern		negate
	extern		abs
	extern		inverse
	extern		degrees
	extern		radians
	extern		fcompare
	extern		atof
	extern		ftoa
	extern		fstatus
	extern		pow
	extern		root
	extern		min
	extern		fraction
	extern		asin
	extern		acos
	extern		atan
	extern		atan2

;-------------------- long Integer Routines -----------------------------------

	extern		lwriteA
	extern		lwriteB
	extern		lread
	extern		lset
	extern		ladd
	extern		lsub
	extern		lmul
	extern		ldiv
	extern		atol
	extern		ltoa
	extern		ludiv
	extern		lcompare
	extern		lucompare
	extern		lstatus
	extern		lnegate
	extern		labs

;-------------------- misc routines -------------------------------------------

	extern		sync
	extern		float
	extern		fix
	extern		readstr
	extern		left
	extern		right
	extern		ieeeMode
	extern		picMode

	extern		fpu_break
	extern		fpu_traceOff
	extern		fpu_traceOn
	extern		fpu_traceStr
	extern		fpu_checksum
	extern		fpu_version

;-------------------- load routines -------------------------------------------

	extern		load_floatByte
	extern		load_floatUbyte
	extern		load_floatWord
	extern		load_floatUword
	extern		load_zero
	extern		load_one
	extern		load_e
	extern		load_pi
	extern		load_longByte
	extern		load_longUbyte
	extern		load_longByte
	extern		load_longUbyte
